@@ -6,7 +6,8 @@ source("main_sonar.r");
       opts = tdmOptsDefaultsSet();    # set initial defaults for many elements of opts. See tdmOptsDefaults.r
                                       # for the list of those elements and many explanatory comments
       opts$filename = "sonar.txt"
-      if (exists("GRAPHDEV")) opts$GRAPHDEV = GRAPHDEV;   # choices are ["win" | "pdf | "non"], default = "win"
+      opts$ncopies=100;
+      if (exists("GRAPHDEV")) opts$GD.DEVICE = GRAPHDEV;   # choices are ["win" | "pdf | "non"], default = "win"
       result=main_sonar(opts);
 
 setwd(oldwd);
