@@ -4,23 +4,21 @@
 #
 # Example usage:
 #       result <- main_sonar();
-# Use "browser()" if you want to look at the variables inside
 #
 # Author: Wolfgang Konen, FHK, Sep'2010 - Dec'2010
 #
-main_sonar <- function(opts=NULL) {          
+main_sonar <- function(opts=NULL,dset=NULL) {          
 
     if (is.null(opts)) {
       opts = tdmOptsDefaultsSet();    # set initial defaults for many elements of opts. See tdmOptsDefaults.r
                                       # for the list of those elements and many explanatory comments                                                                                                         
       opts$filename = "sonar.txt"
       opts$filesuffix = ".txt"
+      opts$READ.CMD = "read.csv2(file=paste(opts$dir.data, filename, sep=\"\"), dec=\".\", sep=\",\",header=FALSE)"
       opts$data.title <- "Sonar Data"
 
       opts$SRF.kind = "xperc"         # no variable ranking, no variable selection
-      opts$MOD.method="RF";               # ["RF"|"MC.RF"|"SVM"|"NB"]: use [RF| MetaCost-RF| SVM| Naive Bayes] in tdmClassifyLoop
-      opts$PRE.PCA = "linear"         # ["none"|"linear"|"kernel"] PCA preprocessing
-      opts$PRE.npc = 7      # tmp
+      opts$MOD.method="RF";           # ["RF"|"MC.RF"|"SVM"|"NB"]: use [RF| MetaCost-RF| SVM| Naive Bayes] in tdmClassifyLoop
       
       # Activate the following four lines to run the RF.default-(main_sonar.r)-experiment in Benchmark-Datasets.doc:
       opts$GD.DEVICE = "pdf";
@@ -30,13 +28,15 @@ main_sonar <- function(opts=NULL) {
     }
     opts <- tdmOptsDefaultsFill(opts);  # fill in all opts params which are not yet set (see tdmOptsDefaults.r)
     
-    tdmGraAndLogInitialize(opts);     # init graphics and log file
+    gdObj <- tdmGraAndLogInitialize(opts);     # init graphics and log file
 
     #===============================================
     # PART 1: READ DATA
     #===============================================
-    cat1(opts,opts$filename,": Read data ...\n")
-    dset <- read.csv2(file=paste(opts$dir.data, opts$filename, sep=""), dec=".", sep=",",header=FALSE)
+    if (is.null(dset)) {
+      cat1(opts,opts$filename,": Read data ...\n")
+      dset <- tdmReadData(opts);
+    }
     names(dset)[61] <- "Class"
 
     # alternative way (but this requires mlbench):
@@ -50,15 +50,6 @@ main_sonar <- function(opts=NULL) {
     # which variables are input variables (in this case all others):
     input.variables <- setdiff(names(dset), c(response.variable,ID.variable))
 
-    if (opts$PRE.npc>0 | opts$PRE.PCA!="none") {
-      # a) do PCA on the numeric variables, if opts$PRE.PCA!="none"
-      # b) add monomials of degree 2 for the first opts$PRE.npc numeric variables
-      numeric.variables=input.variables;
-      pca <- tdmPrePCA(dset,numeric.variables,opts);   # see tdmPreprocUtils.r
-      dset <- pca$dset;
-      input.variables <- pca$numeric.variables;
-    }
-
     #===============================================
     # PART 2 - 6
     #===============================================
@@ -67,7 +58,7 @@ main_sonar <- function(opts=NULL) {
     # print summary output and attach certain columns (here: y,sd.y,dset) to list result:
     result <- tdmClassifySummary(result,opts,dset);
 
-    tdmGraAndLogFinalize(opts);      # close graphics and log file
+    tdmGraAndLogFinalize(opts,gdObj);      # close graphics and log file
     
     result;  
 }
