@@ -1,4 +1,4 @@
-tdm <- list(tdmPath=NULL  # "../../../tdm" #  source R-files for TDMR from this dir. If NULL, load instead the library TDMR 
+tdm <- list(tdmPath= "../../../tdm" # NULL  #  source R-files for TDMR from this dir. If NULL, load instead the library TDMR 
             , unbiasedFunc="unbiasedRun"
             , umode=c("CV")     # ,"RSUB"
             , mainFile="main_sonar.r"
@@ -9,14 +9,14 @@ tdm <- list(tdmPath=NULL  # "../../../tdm" #  source R-files for TDMR from this
             , nrun=5, nfold=2          # repeats and CV-folds for the unbiased runs
             , optsVerbosity=0           # the verbosity for the unbiased runs
             , withParams=TRUE
-            , nExperim=2
+            , nExperim=1
             , parallelCPUs = 1         # [1] 1: sequential, >1: parallel with snowFall and this many cpus
             );
             
 #--
 #-- the following 3 lines are only needed if you want to initialize for parallel execution OR if you want to 
 #-- run the developer sources in tdm$tdmPath; otherwise a simple  "require(TDMR);"  will do.
-tdm$theSpotPath <- NA;
+tdm$theSpotPath <- "USE.SOURCE"; # NA;
 start.tdm.path <- ifelse(is.null(tdm$tdmPath),.find.package("TDMR"),paste(tdm$tdmPath,"inst",sep="/")); 
 source(paste(start.tdm.path,"start.tdm.r",sep="/"),local=T); 
 #require(TDMR);
